==> Epics.uv7.24.tar.gz: epics/ZepMaxdef.h <==
#ifndef  EP_MAX_DEF
#define  EP_MAX_DEF
#define EPMAX_STACK 3000

       !    Max stack size for particle tracking. If there is
       !    no multi-particle produciton, this may be as small
       !    as ~30, but if multipicity of n must be treated,
       !    this must be as large as a few times * n.

#define MAX_MEDIA  20

       !    max number of different media (such as Pb, Si, BGO)

       !         #define MAX_MATRESKA  1000 obsolete

       !    max number of matreska, i.e, component that containes other
       !    components                        

#define MAX_COMPONENT  30000

       !     max number of components definable in Epics

#define MAX_MEDIA_DIR  3

       !     max number of directories where media file is  serached for.
       !     if this is increased, some changes in EPPARM is needed
#define MAX_ATTR   150000
       !     max total number of attributes of the all the components
       !    = max component nubmer x average attributes for 1 component.
       !     ( box has 3, sphere 1,  cyl 2, pipe 3...)
#define MAX_IATTR  50

      !  max number of attributes of an individual component (including
      !  derived attribues in the program).

#define MAX_VERTEX  40
       !     max nubmer of vertexes of a component treatable.
       !     If a volume has a  curved surface (convex), vertex
       !     information is not used; NVTX=0 

#define MAX_SUBD  1000

       !     max number of sub-detectors definable
#define MAX_COMPONENT_IN_SUBD  30000
       !     max number of components in a sub detector
#define MAX_SUBD_REF  1000
       !     max number of sub detectors that can be referred

#define MAX_DISPLAY  800

       !    max number of components displayable with a moderate cpu time

#define MAX_ERR_DIR_COS  3.d-3
       !     max error permissilbe in sum of direction cos^2

#define EPS_FOR_90  1.d-5

       !     scaler prod. of orthogonal unit vector must be <  this.
#define MAX_NEW_STRUC  15

       !     max number of new structures definable by the user

#define MAX_ELEMENTS  20

       !     max number of elements(atoms) in a medium.

#define MAX_EQUATE  48
       !    max number of #equate definable
#define MAX_CN_AREA  40000
       !  max total number of comp. that appear as contained by
       !    other comp.s
#define EPMAX_COMMENT  200
       !   max number of comment lines keptable and printable later
#define EPMAX_UHOOKC 5
#define EPMAX_UHOOKI 10
#define EPMAX_UHOOKR 10
      !     number of user definable character, integer, real*8
      !     variables in sepicsfile
#endif

==> Epics.uv8.64.tar.gz: epics/ZepMaxdef.h <==
#ifndef  EP_MAX_DEF
#define  EP_MAX_DEF
#define EPMAX_STACK 3000

       !    Max stack size for particle tracking. If there is
       !    no multi-particle produciton, this may be as small
       !    as ~30, but if multipicity of n must be treated,
       !    this must be as large as a few times * n.

#define MAX_MEDIA  20

       !    max number of different media (such as Pb, Si, BGO)

       !         #define MAX_MATRESKA  1000 obsolete

       !    max number of matreska, i.e, component that containes other
       !    components                        

#define MAX_COMPONENT  40000

       !     max number of components definable in Epics

#define MAX_MEDIA_DIR  3

       !     max number of directories where media file is  serached for.
       !     if this is increased, some changes in EPPARM is needed
#define MAX_ATTR   150000
       !     max total number of attributes of the all the components
       !    = max component nubmer x average attributes for 1 component.
       !     ( box has 3, sphere 1,  cyl 2, pipe 3...)
#define MAX_IATTR  50

      !  max number of attributes of an individual component (including
      !  derived attribues in the program).

#define MAX_VERTEX  40
       !     max nubmer of vertexes of a component treatable.
       !     If a volume has a  curved surface (convex), vertex
       !     information is not used; NVTX=0 

#define MAX_SUBD  2000

       !     max number of sub-detectors definable
#define MAX_COMPONENT_IN_SUBD  40000
       !     max number of components in a sub detector
#define MAX_SUBD_REF  2000
       !     max number of sub detectors that can be referred

#define MAX_DISPLAY  800

       !    max number of components displayable with a moderate cpu time

#define MAX_ERR_DIR_COS  3.d-3
       !     max error permissilbe in sum of direction cos^2

#define EPS_FOR_90  1.d-5

       !     scaler prod. of orthogonal unit vector must be <  this.
#define MAX_NEW_STRUC  15

       !     max number of new structures definable by the user

#define MAX_ELEMENTS  20

       !     max number of elements(atoms) in a medium.

#define MAX_EQUATE  48
       !    max number of #equate definable
cc#define MAX_CN_AREA  40000
#define MAX_CN_AREA  100000
       !  max total number of comp. that appear as contained by
       !    other comp.s
#define EPMAX_COMMENT  200
       !   max number of comment lines keptable and printable later
#define EPMAX_UHOOKC 5
#define EPMAX_UHOOKI 10
#define EPMAX_UHOOKR 10
      !     number of user definable character, integer, real*8
      !     variables in sepicsfile
#endif
